@@ -7,6 +7,7 @@ from discogui.screenrect import ScreenRect
 import Image
 import ImageDraw
 
+
 def draw_textrect(im, rect, text=None, color='red'):
     '''
     draw rectangle and text in center
@@ -19,7 +20,8 @@ def draw_textrect(im, rect, text=None, color='red'):
         rtext.center = ScreenRect(rect).center
         draw.text(rtext.topleft, text, fill=color)
     return im
-        
+
+
 def draw_indexed_rect_list(im, lsrect, color='red'):
     '''
     draw rectangles and index in center
@@ -29,16 +31,13 @@ def draw_indexed_rect_list(im, lsrect, color='red'):
         im = draw_textrect(im, x, str(index), color=color)
         index += 1
     return im
-    
-def _test(): 
-    im = Image.new('RGB', (522, 222), 'grey')   
+
+
+def _test():
+    im = Image.new('RGB', (522, 222), 'grey')
     x = draw_indexed_rect_list(im,
-        [(1, 111, 111, 61), (221, 1, 111, 61), ] 
-        ,)
+                               [(1, 111, 111, 61), (221, 1, 111, 61), ],)
     x.show()
-    
+
 if __name__ == '__main__':
     _test()
-    
-    
-    
