@@ -7,12 +7,14 @@ from discogui.buttons import discover_buttons
 from easyprocess import EasyProcess
 from pyvirtualdisplay import Display
 
+
 def main():
-    buttons = Display().wrap(
-                    EasyProcess('zenity --question').wrap(
-                                          discover_buttons, delay=1))
-    print buttons()
-    
+    with Display():
+        with EasyProcess('zenity --question') as p:
+            p.sleep(10)
+            buttons = discover_buttons()
+    print buttons
+
 
 if __name__ == '__main__':
-    main()
\ No newline at end of file
+    main()
