@@ -8,25 +8,25 @@ from discogui.draw import draw_indexed_rect_list
 from discogui.hover import active_rectangles
 from discogui.imgutil import autocrop
 from easyprocess import EasyProcess
-from pyscreenshot import grab
-from pyvirtualdisplay import Display
+# from pyscreenshot import grab
+# from pyvirtualdisplay import Display
+from pyvirtualdisplay.smartdisplay import SmartDisplay
+# import time
+
 
 def main():
-    screen = Display(size=(640,480)).start()
-    gnumeric= EasyProcess('gnumeric').start().sleep(2)
-    
-    img = grab()
-    rectangles = active_rectangles()
-    print rectangles
-    
-    gnumeric.stop()
-    screen.stop()
-    
+    with SmartDisplay(size=(640, 480)) as disp:
+        with EasyProcess('gnumeric'):
+#            time.sleep(2)
+            img = disp.waitgrab(timeout=60)
+            rectangles = active_rectangles()
+            print rectangles
+
     img = draw_indexed_rect_list(img, rectangles)
     img = autocrop(img)
-    
+
     # display results
     img.show()
 
-if __name__=='__main__':
-    main()
\ No newline at end of file
+if __name__ == '__main__':
+    main()
